@@ -3,7 +3,7 @@ from http import HTTPStatus
 import requests
 
 from cachetools import TTLCache
-from jose import jwt
+from jose import jwt, ExpiredSignatureError
 
 _LOCAL_CACHE_MAX_SIZE = 2048
 _LOCAL_CACHE_TTL_IN_SECONDS = 60 * 60
@@ -36,7 +36,11 @@ class OpenIDConnectAuth:
         )
 
     def authorize(self, access_token: str, required_permission: str = None) -> str:
-        self.validate_access_token(access_token)
+        try:
+            self.validate_access_token(access_token)
+        except ExpiredSignatureError:
+            raise OIDCAuthError("Access token signature is expired")
+
         if required_permission and not self._has_permission(
             access_token, required_permission
         ):
