@@ -32,6 +32,12 @@ def test_dict_to_user_profile():
     assert "gcm-is-fcm-is-gcm" == user_profile.push_notification_id
 
 
+def test_dict_to_user_profile_with_primary_app():
+    user_dict = {"primary_app": "chalo", **user_profile_dict}
+    user_profile = UserProfile.from_dict(user_dict)
+    assert user_profile.primary_app == "chalo"
+
+
 def test_dict_to_user_profile_for_incomplete_user_profile():
     user_profile = UserProfile.from_dict(incomplete_user_profile_dict)
     assert user_profile.name is None
@@ -75,6 +81,12 @@ def test_user_profile_with_no_name_gender_to_dict():
     assert user_profile_dict_with_no_name_or_gender["id"] == user_profile_new_dict["id"]
 
 
+def test_user_profile_with_primary_app_to_dict():
+    user_profile = UserProfile.from_dict(user_dict)
+    user_profile.primary_app = "chalo"
+    assert user_profile.to_dict()["primary_app"] == "chalo"
+
+
 def test_dict_to_session():
     session = Session.from_dict(session_response)
     assert session.user.id == "30944af3-dfe7-45e5-a860-31ac4a18bc69"
